@@ -6,35 +6,39 @@ from configparser import ConfigParser
 
 class tfidf_pipeline:
 
-    def __init__(self, config_path: str):
-        config = ConfigParser()
-        path = config_path
-        config.read(path)
-        self.Dot = int(config['TFIDF']['Dot'])
-        self.Supported_inputs = config['TFIDF']['Supported_inputs']
-        self.Verbose = config['TFIDF']['Verbose']
+    def __init__(self):
+        # config = ConfigParser()
+        # path = config_path
+        # config.read(path)
+        # self.Dot = int(config['TFIDF']['Dot'])
+        self.Dot = 10
+        # self.Supported_inputs = config['TFIDF']['Supported_inputs']
+        self.Verbose = True
+        self.num_words = None
+        # c_var = config['TFIDF']['num_words']
+        # if c_var == 'None':
+        #     self.num_words = None
+        # else:
+        #     self.num_words = int(c_var)
 
-        c_var = config['TFIDF']['num_words']
-        if c_var == 'None':
-            self.num_words = None
-        else:
-            self.num_words = int(c_var)
-
-        if config['TFIDF']['Input_data_type'] not in self.Supported_inputs:
-            raise TypeError(
-                f"Selected input data type ({config['TFIDF']['Input_data_type']}) not currently supported as an "
-                f"input. \n Please format the input in on of the supported formats. \n Supported formats: "
-                f"{self.Supported_inputs}")
-        self.Input_data_type = config['TFIDF']['Input_data_type']
+        # if config['TFIDF']['Input_data_type'] not in self.Supported_inputs:
+        #     raise TypeError(
+        #         f"Selected input data type ({config['TFIDF']['Input_data_type']}) not currently supported as an "
+        #         f"input. \n Please format the input in on of the supported formats. \n Supported formats: "
+        #         f"{self.Supported_inputs}")
+        # self.Input_data_type = config['TFIDF']['Input_data_type']
+    def print_all_methods(self):
+        object_methods = [method_name for method_name in dir(self) if callable(getattr(self, method_name))]
+        print(object_methods)
 
     #### Check input data type ####
     def check_data_type(self, data):
         """self function that checks if the input data type is known to be compatible with the remaining functions"""
-        if type(data).__name__ not in self.Supported_inputs:
+        if type(data).__name__ != 'list':
             raise TypeError(
                 f"Input type ({type(data)}) not currently supported as an input. "
                 f"\n Please format the input in on of the supported formats. "
-                f"\n Supported formats: {self.Supported_inputs}")
+                f"\n Supported formats: list")
 
     #### calc_TFIDF ####
     def calc_tfidf(self, data: list, labels: list):
@@ -71,7 +75,7 @@ class tfidf_pipeline:
         are returned as a list of lists where index 0 is the 1-2 sigma outliers, index 1 is the 2-3 sigma outlers,
         and index 2 is 3-> outliers The outliers for the negative class is stored in [0] The outliers for the
         positive class is stored in [1] """
-        self.inliers, self.outliers = pf.sigma_splitter_TF_IDF(self.score)
+        self.inliers, self.outliers = pf.sigma_splitter_TF_IDF(self.get_score)
         if self.Verbose:
             print(
                 f" Inliers added under 'self.Inliers' \n Positive outliers added under 'self.Pos_outliers' \n use "
@@ -216,8 +220,6 @@ class tfidf_pipeline:
             words_all.append(words)
         return words_all
 
-    # #### SAVE LIST TO TXTFILE  ####
-
     #####  CONFIG  ###
     def set_verbose(self, bol: bool= False):
         """
@@ -248,15 +250,24 @@ class tfidf_pipeline:
     def get_dot(self):
         return self.Dot
 
-    #### Input_data_type ####
-    def get_input_data_type(self):
-        return self.Input_data_type
-
-    ####
-    def set_input_data_type(self, string: str):
-        if string not in self.Supported_inputs:
-            raise TypeError(
-                f"Selected input data type ({string}) not currently supported as an input. "
-                f"\n Please format the input in on of the supported formats. "
-                f"\n Supported formats: {self.Supported_inputs}")
-        self.Input_data_type = string
+    def print_outliers_to_terminal(lst: List[List[list]], sort: bool = True):
+        """
+        prints the input text outliers to the terminal window with sorted into the sigma outlier
+        @param path: str
+        @param lst: list
+        @param sort: bool
+        """
+        if sort:
+            lst.sort()
+        else:
+            pass
+        sigmas = ["1", "2", "3"]
+        for outliers, sigma in zip(lst, sigmas):
+            if sort:
+                print(f"Printing {sigma}-sigma outliers, alphabetically sorted")
+            else:
+                print(f"Printing {sigma}-sigma outliers")
+            print(20 * "#")
+            for word in outliers:
+                print(f"{word}")
+            print(20 * "#")
\ No newline at end of file
